StarsConfig class

Constructors

StarsConfig({int starCount = 75, double minStarSize = .5, double maxStarSize = 3, List<Color> colors = const <Color>[Colors.white]})
const

Properties

colors List<Color>
final
hashCode int
The hash code for this object.
no setterinherited
maxStarSize double
final
minStarSize double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited